@@ -4,19 +4,19 @@ use proc_macro2::Ident;
 pub(super) fn generate_vectorizable_extension(ty: &Ident) -> String {
     format!(
         r#"extension {ty}: Vectorizable {{
-    static func vecOfSelfNew() -> UnsafeMutableRawPointer {{
+    public static func vecOfSelfNew() -> UnsafeMutableRawPointer {{
         __swift_bridge__$Vec_{ty}$new()
     }}
 
-    static func vecOfSelfFree(vecPtr: UnsafeMutableRawPointer) {{
+    public static func vecOfSelfFree(vecPtr: UnsafeMutableRawPointer) {{
         __swift_bridge__$Vec_{ty}$drop(vecPtr)
     }}
 
-    static func vecOfSelfPush(vecPtr: UnsafeMutableRawPointer, value: {ty}) {{
+    public static func vecOfSelfPush(vecPtr: UnsafeMutableRawPointer, value: {ty}) {{
         __swift_bridge__$Vec_{ty}$push(vecPtr, {{value.isOwned = false; return value.ptr;}}())
     }}
 
-    static func vecOfSelfPop(vecPtr: UnsafeMutableRawPointer) -> Optional<Self> {{
+    public static func vecOfSelfPop(vecPtr: UnsafeMutableRawPointer) -> Optional<Self> {{
         let pointer = __swift_bridge__$Vec_{ty}$pop(vecPtr)
         if pointer == nil {{
             return nil
@@ -25,7 +25,7 @@ pub(super) fn generate_vectorizable_extension(ty: &Ident) -> String {
         }}
     }}
 
-    static func vecOfSelfGet(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<{ty}Ref> {{
+    public static func vecOfSelfGet(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<{ty}Ref> {{
         let pointer = __swift_bridge__$Vec_{ty}$get(vecPtr, index)
         if pointer == nil {{
             return nil
@@ -34,7 +34,7 @@ pub(super) fn generate_vectorizable_extension(ty: &Ident) -> String {
         }}
     }}
 
-    static func vecOfSelfGetMut(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<{ty}RefMut> {{
+    public static func vecOfSelfGetMut(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<{ty}RefMut> {{
         let pointer = __swift_bridge__$Vec_{ty}$get_mut(vecPtr, index)
         if pointer == nil {{
             return nil
@@ -43,7 +43,7 @@ pub(super) fn generate_vectorizable_extension(ty: &Ident) -> String {
         }}
     }}
 
-    static func vecOfSelfLen(vecPtr: UnsafeMutableRawPointer) -> UInt {{
+    public static func vecOfSelfLen(vecPtr: UnsafeMutableRawPointer) -> UInt {{
         __swift_bridge__$Vec_{ty}$len(vecPtr)
     }}
 }}
@@ -64,19 +64,19 @@ mod tests {
     fn generates_vectorizable_extension() {
         let expected = r#"
 extension ARustType: Vectorizable {
-    static func vecOfSelfNew() -> UnsafeMutableRawPointer {
+    public static func vecOfSelfNew() -> UnsafeMutableRawPointer {
         __swift_bridge__$Vec_ARustType$new()
     }
 
-    static func vecOfSelfFree(vecPtr: UnsafeMutableRawPointer) {
+    public static func vecOfSelfFree(vecPtr: UnsafeMutableRawPointer) {
         __swift_bridge__$Vec_ARustType$drop(vecPtr)
     }
 
-    static func vecOfSelfPush(vecPtr: UnsafeMutableRawPointer, value: ARustType) {
+    public static func vecOfSelfPush(vecPtr: UnsafeMutableRawPointer, value: ARustType) {
         __swift_bridge__$Vec_ARustType$push(vecPtr, {value.isOwned = false; return value.ptr;}())
     }
 
-    static func vecOfSelfPop(vecPtr: UnsafeMutableRawPointer) -> Optional<Self> {
+    public static func vecOfSelfPop(vecPtr: UnsafeMutableRawPointer) -> Optional<Self> {
         let pointer = __swift_bridge__$Vec_ARustType$pop(vecPtr)
         if pointer == nil {
             return nil
@@ -85,7 +85,7 @@ extension ARustType: Vectorizable {
         }
     }
 
-    static func vecOfSelfGet(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<ARustTypeRef> {
+    public static func vecOfSelfGet(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<ARustTypeRef> {
         let pointer = __swift_bridge__$Vec_ARustType$get(vecPtr, index)
         if pointer == nil {
             return nil
@@ -94,7 +94,7 @@ extension ARustType: Vectorizable {
         }
     }
 
-    static func vecOfSelfGetMut(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<ARustTypeRefMut> {
+    public static func vecOfSelfGetMut(vecPtr: UnsafeMutableRawPointer, index: UInt) -> Optional<ARustTypeRefMut> {
         let pointer = __swift_bridge__$Vec_ARustType$get_mut(vecPtr, index)
         if pointer == nil {
             return nil
@@ -103,7 +103,7 @@ extension ARustType: Vectorizable {
         }
     }
 
-    static func vecOfSelfLen(vecPtr: UnsafeMutableRawPointer) -> UInt {
+    public static func vecOfSelfLen(vecPtr: UnsafeMutableRawPointer) -> UInt {
         __swift_bridge__$Vec_ARustType$len(vecPtr)
     }
 }
